@@ -18,7 +18,7 @@ log = logging.getLogger(__name__)
 
 
 class MultiqcModule(BaseMultiqcModule):
-    """ HiC-Pro module, parses log and stats files saved by HiC-Pro. """
+    """HiC-Pro module, parses log and stats files saved by HiC-Pro."""
 
     def __init__(self):
 
@@ -86,8 +86,8 @@ class MultiqcModule(BaseMultiqcModule):
             anchor="hicpro-pairing",
             description="Pairing of single-end mapping.",
             helptext="""
-            HiC-Pro combines aligned reads as pairs. Singleton, low quality pairs or 
-            pairs involving multi-mapped reads are usually discarded. Note that the filtering 
+            HiC-Pro combines aligned reads as pairs. Singleton, low quality pairs or
+            pairs involving multi-mapped reads are usually discarded. Note that the filtering
             at pairing level can change accrding to the parameters used.""",
             plot=self.hicpro_pairing_chart(),
         )
@@ -97,12 +97,12 @@ class MultiqcModule(BaseMultiqcModule):
             anchor="hicpro-filtering",
             description="Filtering of read pairs.",
             helptext="""
-            Aligned read pairs are filtered to select valid 3C products from two 
-            different restriction fragments. Read pairs coming from the same fragments, 
+            Aligned read pairs are filtered to select valid 3C products from two
+            different restriction fragments. Read pairs coming from the same fragments,
             such as self-ligation or unligated (danging-end) fragments, are discarded.
             Ligation products involving neighboring restriction fragment (religation) are also discarded.
             Filtered pairs correspond to ligation products discarded based on the range of insert/fragment sizes defined
-            in the analysis. Finally, as the ligation should be a random process, valid read pairs from all 
+            in the analysis. Finally, as the ligation should be a random process, valid read pairs from all
             orientations (R=Reverse, F=forward) are expected to be observed in the same proportion.""",
             plot=self.hicpro_filtering_chart(),
         )
@@ -112,7 +112,7 @@ class MultiqcModule(BaseMultiqcModule):
             anchor="hicpro-rmdup",
             description="Contacts statistics after duplicates removal.",
             helptext="""
-            Description of contact frequency after duplicates removal. Intra-chromosomal 
+            Description of contact frequency after duplicates removal. Intra-chromosomal
             (*cis*) interaction are expected to be more frequent than inter-chromosomal contacts (*trans*)""",
             plot=self.hicpro_contact_chart(),
         )
@@ -124,7 +124,7 @@ class MultiqcModule(BaseMultiqcModule):
                 anchor="hicpro-asan",
                 description="Assignment of valid interactions (afer duplicates removal) to parental alleles.",
                 helptext="""
-                Description of allele-specific contacts. Valid interactions (0-1 and 1-1, resp. 0-2, 2-2) 
+                Description of allele-specific contacts. Valid interactions (0-1 and 1-1, resp. 0-2, 2-2)
                 are used to build the genome1 (resp. genome2) parental maps.""",
                 plot=allele_plot,
             )
@@ -136,15 +136,14 @@ class MultiqcModule(BaseMultiqcModule):
                 anchor="hicpro-cap",
                 description="Selection of interactions overlaping the targeted region(s).",
                 helptext="""
-                Description of capture efficiency. Valid interactions with either two (capture-capture) or 
+                Description of capture efficiency. Valid interactions with either two (capture-capture) or
                 one (capture-reporter) interactors overlapping with the target(s) are reported.""",
                 plot=capture_plot,
             )
 
     def parse_hicpro_stats(self, f, rsection):
-        """ Parse a HiC-Pro stat file """
-        s_name = self.clean_s_name(os.path.basename(f["root"]), os.path.dirname(f["root"]))
-
+        """Parse a HiC-Pro stat file"""
+        s_name = self.clean_s_name(os.path.basename(f["root"]), root=os.path.dirname(f["root"]))
         if s_name not in self.hicpro_data.keys():
             self.hicpro_data[s_name] = {}
 
@@ -157,7 +156,7 @@ class MultiqcModule(BaseMultiqcModule):
                 self.hicpro_data[s_name][s[0]] = int(s[1])
 
     def hicpro_stats_table(self):
-        """ Add HiC-Pro stats to the general stats table """
+        """Add HiC-Pro stats to the general stats table"""
         headers = OrderedDict()
 
         headers["percent_duplicates"] = {
@@ -270,7 +269,7 @@ class MultiqcModule(BaseMultiqcModule):
         self.general_stats_addcols(self.hicpro_data, headers, "HiC-Pro")
 
     def hicpro_mapping_chart(self):
-        """ Generate the HiC-Pro Aligned reads plot """
+        """Generate the HiC-Pro Aligned reads plot"""
 
         # Specify the order of the different possible categories
         keys = OrderedDict()
@@ -303,7 +302,7 @@ class MultiqcModule(BaseMultiqcModule):
         return bargraph.plot(data, [keys, keys], config)
 
     def hicpro_pairing_chart(self):
-        """ Generate Pairing chart """
+        """Generate Pairing chart"""
 
         # Specify the order of the different possible categories
         keys = OrderedDict()
@@ -324,7 +323,7 @@ class MultiqcModule(BaseMultiqcModule):
         return bargraph.plot(self.hicpro_data, keys, config)
 
     def hicpro_filtering_chart(self):
-        """ Generate the HiC-Pro filtering plot """
+        """Generate the HiC-Pro filtering plot"""
 
         # Specify the order of the different possible categories
         keys = OrderedDict()
@@ -349,7 +348,7 @@ class MultiqcModule(BaseMultiqcModule):
         return bargraph.plot(self.hicpro_data, keys, config)
 
     def hicpro_contact_chart(self):
-        """ Generate the HiC-Pro interaction plot """
+        """Generate the HiC-Pro interaction plot"""
 
         # Specify the order of the different possible categories
         keys = OrderedDict()
@@ -369,7 +368,7 @@ class MultiqcModule(BaseMultiqcModule):
         return bargraph.plot(self.hicpro_data, keys, config)
 
     def hicpro_as_chart(self):
-        """ Generate Allele-specific plot"""
+        """Generate Allele-specific plot"""
 
         keys = OrderedDict()
         keys["Valid_pairs_from_ref_genome_(1-1)"] = {"color": "#e6550d", "name": "Genome1 specific read pairs (1-1)"}
@@ -411,7 +410,7 @@ class MultiqcModule(BaseMultiqcModule):
         return bargraph.plot(self.hicpro_data, keys, config)
 
     def hicpro_capture_chart(self):
-        """ Generate Capture Hi-C plot"""
+        """Generate Capture Hi-C plot"""
 
         keys = OrderedDict()
         keys["valid_pairs_on_target_cap_cap"] = {"color": "#0039e6", "name": "Capture-Capture interactions"}
