@@ -18,6 +18,7 @@ import io
 import jinja2
 import os
 import re
+import rich
 import shutil
 import subprocess
 import sys
@@ -25,6 +26,8 @@ import tempfile
 import time
 import traceback
 
+from rich.syntax import Syntax
+
 try:
     # Python 3 imports
     from urllib.request import urlopen
@@ -37,7 +40,7 @@ except ImportError:
     sys.setdefaultencoding("utf8")
 
 from .plots import table
-from .utils import report, plugin_hooks, megaqc, util_functions, lint_helpers, config, log
+from .utils import report, plugin_hooks, megaqc, util_functions, lint_helpers, config, log, mqc_colour
 
 start_execution_time = time.time()
 logger = config.logger
@@ -86,17 +89,26 @@ logger = config.logger
     "--ignore-samples", "ignore_samples", type=str, multiple=True, help="Ignore sample names (glob expression)"
 )
 @click.option("--ignore-symlinks", "ignore_symlinks", is_flag=True, help="Ignore symlinked directories and files")
+@click.option(
+    "--fn_as_s_name", "use_filename_as_sample_name", is_flag=True, help="Use the log filename as the sample name"
+)
+@click.option(
+    "--replace-names",
+    "replace_names",
+    type=click.Path(exists=True, readable=True),
+    help="Path to TSV file to rename sample names during report generation",
+)
 @click.option(
     "--sample-names",
     "sample_names",
     type=click.Path(exists=True, readable=True),
-    help="File containing alternative sample names",
+    help="Path to TSV file containing alternative sample names for renaming buttons in the report",
 )
 @click.option(
     "--sample-filters",
     "sample_filters",
     type=click.Path(exists=True, readable=True),
-    help="File containing show/hide patterns for the report",
+    help="Path to TSV file containing show/hide patterns for the report",
 )
 @click.option(
     "-l", "--file-list", is_flag=True, help="Supply a file containing a list of file paths to be searched, one per row"
@@ -179,6 +191,8 @@ def run_cli(
     outdir,
     ignore,
     ignore_samples,
+    use_filename_as_sample_name,
+    replace_names,
     sample_names,
     sample_filters,
     file_list,
@@ -203,11 +217,24 @@ def run_cli(
     no_ansi,
     **kwargs,
 ):
+    # Main MultiQC run command for use with the click command line, complete with all click function decorators.
+    # To make it easy to use MultiQC within notebooks and other locations that don't need click, we simply pass the
+    # parsed variables on to a vanilla python function.
+
+    """MultiQC aggregates results from bioinformatics analyses across many samples into a single report.
+
+    It searches a given directory for analysis logs and compiles a HTML report.
+    It's a general use tool, perfect for summarising the output from numerous
+    bioinformatics tools.
+
+    To run, supply with one or more directory to scan for analysis results.
+    To run here, use 'multiqc .'
+
+    See http://multiqc.info for more details.
+
+    Author: Phil Ewels (http://phil.ewels.co.uk)
     """
-    Main MultiQC run command for use with the click command line, complete with all click function decorators.
-    To make it easy to use MultiQC within notebooks and other locations that don't need click, we simply pass the
-    parsed variables on to a vanilla python function.
-    """
+
     # Use keyword arguments in case things get rearranged in the future
     multiqc_run = run(
         analysis_dir=analysis_dir,
@@ -223,6 +250,8 @@ def run_cli(
         outdir=outdir,
         ignore=ignore,
         ignore_samples=ignore_samples,
+        use_filename_as_sample_name=use_filename_as_sample_name,
+        replace_names=replace_names,
         sample_names=sample_names,
         sample_filters=sample_filters,
         file_list=file_list,
@@ -267,6 +296,8 @@ def run(
     outdir=None,
     ignore=(),
     ignore_samples=(),
+    use_filename_as_sample_name=False,
+    replace_names=None,
     sample_names=None,
     sample_filters=None,
     file_list=False,
@@ -311,6 +342,14 @@ def run(
         loglevel = "WARNING"
     log.init_log(logger, loglevel=loglevel, no_ansi=no_ansi)
 
+    console = rich.console.Console(stderr=True, highlight=False, force_terminal=log.force_term_colors())
+    console.print(
+        "\n  [blue]/[/][green]/[/][red]/[/] [bold][link=https://multiqc.info]MultiQC[/link][/] :mag: [dim]| v{}\n".format(
+            config.version
+        )
+    )
+    logger.debug("This is MultiQC v{}".format(config.version))
+
     # Load config files
     plugin_hooks.mqc_trigger("before_config")
     config.mqc_load_userconfig(config_file)
@@ -353,9 +392,9 @@ def run(
     config.analysis_dir = analysis_dir
     if outdir is not None:
         config.output_dir = outdir
-    if no_clean_sname:
-        config.fn_clean_sample_names = False
-        logger.info("Not cleaning sample names")
+    if use_filename_as_sample_name:
+        config.use_filename_as_sample_name = True
+        logger.info("Using log filenames for sample names")
     if make_data_dir:
         config.make_data_dir = True
     if no_data_dir:
@@ -383,6 +422,11 @@ def run(
         config.megaqc_upload = False
     else:
         config.megaqc_upload = True
+    if no_clean_sname:
+        config.fn_clean_sample_names = False
+        logger.info("Not cleaning sample names")
+    if replace_names:
+        config.load_replace_names(replace_names)
     if sample_names:
         config.load_sample_names(sample_names)
     config.load_show_hide(sample_filters)
@@ -402,23 +446,22 @@ def run(
 
     plugin_hooks.mqc_trigger("execution_start")
 
-    logger.info("This is MultiQC v{}".format(config.version))
     logger.debug("Command     : {}".format(" ".join(sys.argv)))
     logger.debug("Working dir : {}".format(os.getcwd()))
     if make_pdf:
         logger.info("--pdf specified. Using non-interactive HTML template.")
-    logger.info("Template    : {}".format(config.template))
+    logger.debug("Template    : {}".format(config.template))
     if lint:
         logger.info("--lint specified. Being strict with validation.")
 
     # Throw a warning if we are running on Python 2
     if sys.version_info[0] < 3:
-        logger.warning(
+        logger.error(
             "You are running MultiQC with Python {}.{}.{}".format(
                 sys.version_info[0], sys.version_info[1], sys.version_info[2]
             )
         )
-        logger.warning("Please upgrade! MultiQC no longer officially supports Python < 3.6")
+        logger.critical("Please upgrade Python! MultiQC does not support Python < 3.6, things will break.")
     else:
         logger.debug("Running Python {}".format(sys.version.replace("\n", " ")))
 
@@ -466,8 +509,6 @@ def run(
         logger.info("Report title: {}".format(config.title))
     if dirs:
         logger.info("Prepending directory to sample names")
-    for d in config.analysis_dir:
-        logger.info("Searching   : {}".format(os.path.abspath(d)))
 
     # Prep module configs
     config.top_modules = [m if type(m) is dict else {m: {}} for m in config.top_modules]
@@ -513,7 +554,7 @@ def run(
 
     if len(getattr(config, "run_modules", {})) > 0:
         run_modules = [m for m in run_modules if list(m.keys())[0] in config.run_modules]
-        logger.info("Only using modules {}".format(", ".join(config.run_modules)))
+        logger.info("Only using modules: {}".format(", ".join(config.run_modules)))
     elif modules_from_tags:
         run_modules = [m for m in run_modules if list(m.keys())[0] in modules_from_tags]
         logger.info("Only using modules with '{}' tag".format(", ".join(module_tag)))
@@ -562,6 +603,8 @@ def run(
         pass  # custom_data not in config
 
     # Get the list of files to search
+    for d in config.analysis_dir:
+        logger.info("Search path : {}".format(os.path.abspath(d)))
     report.get_filelist(run_module_names)
 
     # Run the modules!
@@ -574,6 +617,8 @@ def run(
         try:
             this_module = list(mod_dict.keys())[0]
             mod_cust_config = list(mod_dict.values())[0]
+            if mod_cust_config is None:
+                mod_cust_config = {}
             mod = config.avail_modules[this_module].load()
             mod.mod_cust_config = mod_cust_config  # feels bad doing this, but seems to work
             output = mod()
@@ -619,18 +664,50 @@ def run(
             sys.exit(1)
         except:
             # Flag the error, but carry on
-            logger.error(
-                "Oops! The '{}' MultiQC module broke... \n".format(this_module)
-                + "  Please copy the following traceback and report it at "
-                + "https://github.com/ewels/MultiQC/issues \n"
-                + "  If possible, please include a log file that triggers the error - "
-                + "the last file found was:\n"
-                + "    {}\n".format(report.last_found_file)
-                + ("=" * 60)
-                + "\nModule {} raised an exception: {}".format(this_module, traceback.format_exc())
-                + ("=" * 60)
+            class CustomTraceback:
+                def __rich_console__(self, console: rich.console.Console, options: rich.console.ConsoleOptions):
+                    sys_tb = sys.exc_info()
+                    issue_url = "https://github.com/ewels/MultiQC/issues/new?template=bug_report.md&title={}%20module%20-%20{}".format(
+                        this_module, sys_tb[0].__name__
+                    )
+                    yield (
+                        "Please copy this log and report it at [bright_blue][link={}]https://github.com/ewels/MultiQC/issues[/link][/] \n"
+                        "[bold underline]Please attach a file that triggers the error.[/] The last file found was: [green]{}[/]\n".format(
+                            issue_url, report.last_found_file
+                        )
+                    )
+                    yield Syntax(traceback.format_exc(), "python")
+
+                def __rich_measure__(self, console: rich.console.Console, options: rich.console.ConsoleOptions):
+                    tb_width = max([len(l) for l in traceback.format_exc().split("\n")])
+                    try:
+                        log_width = 71 + len(report.last_found_file)
+                    except TypeError:
+                        log_width = 71
+                    panel_width = max(tb_width, log_width)
+                    return rich.console.Measurement(panel_width, panel_width)
+
+            console = rich.console.Console(stderr=True, force_terminal=log.force_term_colors())
+            console.print(
+                rich.panel.Panel(
+                    CustomTraceback(),
+                    title="Oops! The '[underline]{}[/]' MultiQC module broke...".format(this_module),
+                    expand=False,
+                    border_style="red",
+                    style="on #272822",
+                )
             )
+            # Still log.debug this so that it ends up in the log file - above is just stderr for now
+            logger.debug(
+                "Oops! The '{}' MultiQC module broke...\n".format(this_module)
+                + ("=" * 80)
+                + "\n"
+                + traceback.format_exc()
+                + ("=" * 80)
+            )
+            # Exit code 1 for CI failures etc
             sys_exit_code = 1
+
         report.runtimes["mods"][run_module_names[mod_idx]] = time.time() - mod_starttime
     report.runtimes["total_mods"] = time.time() - total_mods_starttime
 
@@ -718,7 +795,7 @@ def run(
                 "mqc-generalstats-{}-{}".format(ns_html, h[k]["rid"])
             )
     # Generate the General Statistics HTML & write to file
-    if len(report.general_stats_data) > 0:
+    if len(report.general_stats_data) > 0 and not config.skip_generalstats:
         pconfig = {
             "id": "general_stats_table",
             "table_title": "General Statistics",
@@ -944,6 +1021,18 @@ def run(
         logger.info(" - {:.2f}s: Compressing report data".format(report.runtimes["total_compression"]))
         logger.info("For more information, see the 'Run Time' section in {}".format(os.path.relpath(config.output_fn)))
 
+    if report.num_mpl_plots > 0 and not config.plots_force_flat:
+        logger.warning(
+            "{} flat-image plot{} used in the report due to large sample numbers".format(
+                report.num_mpl_plots, "s" if report.num_mpl_plots > 1 else ""
+            )
+        )
+        console.print(
+            "[blue]|           multiqc[/] | "
+            "To force interactive plots, use the [yellow]'--interactive'[/] flag. "
+            "See the [link=https://multiqc.info/docs/#flat--interactive-plots]documentation[/link]."
+        )
+
     if lint and len(report.lint_errors) > 0:
         logger.error("Found {} linting errors!\n{}".format(len(report.lint_errors), "\n".join(report.lint_errors)))
         sys_exit_code = 1
